@@ -219,12 +219,12 @@ qbool Rulesets_RestrictParticles(void)
 
 qbool Rulesets_RestrictIPC(void)
 {
-	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictIPC;
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictIPC && cls.server_adr.type != NA_LOOPBACK;;
 }
 
 qbool Rulesets_RestrictExec(void)
 {
-	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictExec;
+	return cls.state == ca_active && !cl.spectator && !cls.demoplayback && !cl.standby && rulesetDef.restrictExec && cls.server_adr.type != NA_LOOPBACK;
 }
 
 qbool Rulesets_RestrictSetCalc(void)
